@@ -18,6 +18,8 @@ BEGIN { $fields = {
 	"customer_email" => new WWW::Shopify::Field::String::Email(),
 	"domain" => new WWW::Shopify::Field::String::Hostname(),
 	"email" => new WWW::Shopify::Field::String::Email(),
+	"google_apps_domain" => new WWW::Shopify::Field::String::Hostname::Shopify(),
+	"google_apps_login_enabled" => new WWW::Shopify::Field::Boolean(),
 	"name" => new WWW::Shopify::Field::String::Words(1, 3),
 	"phone" => new WWW::Shopify::Field::String::Phone(),
 	"province" => new WWW::Shopify::Field::String::Words(1),
